pub struct DurationHistogram { /* fields omitted */ }
A small wrapper around Histogram to handle the special case
of duration buckets.
This Histogram will handle the correct granularity for logging
time duration in a way that fits the used buckets.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.